# Cytosim's C++ source code

Most source code is written in [C++11](https://en.wikipedia.org/wiki/C++11)

# Essential code

- [**base**](base) : List, Nodes, Arrays, Exceptions, etc.
- [**math**](math) : Vectors, Matrices, Quaternion, Random Number Generator, etc.
- [**sim**](sim) : Mecable, Fiber, etc.

# GUI code

- [**disp**](disp) : Classes used to build *play*: `View`, `Colors`, `GLapp`, etc.
- [**play**](play) : Code for Cytosim's GUI `play`

# Python code
- [**cpython**](cpython) : Python interface to cytosim

# Other code

- [**tools**](tools) : Cytosim accessory programs: `report`, `frametool`, etc.
- [**test**](test) : test programs: `test_blas`, `test_math`, etc.
- [**SFMT**](SFMT) : Copy of Mersenne Twister, a random number generator

# More code

- [**cytomaster**](misc/cytomaster) : a program to control cytosim during installation
- [**blank**](misc/blank) : a demo GUI interface based on Cytosim's toolset
